# Richdata
Helpers for Data Engineering
## Generate
```shell
python setup.py sdist
```
## Upload
```shell
twine upload --skip-existing dist/*
```

## Reinstall
```shell
pip install --upgrade --force-reinstall Richdata
```

## Special install
Sample of special installing
```shell
pip install Richdata[sqlserver]
pip install Richdata[postgres]
pip install Richdata[bigquery]
pip install Richdata[sqlserver,postgres,bigquery]
pip install Richdata[all]
```
## Using samples
### Sample SQLServer
comming son
### Sample PostgreSQL
comming son
### Sample Bigquery
comming son
### Sample MongoDB
work in progress
### Sample MySQL
work in progress
### Sample jupyter